From 76f29c593499d054d1938c0296080562f4ae0ffa Mon Sep 17 00:00:00 2001
From: Serge <5920850+seerge@users.noreply.github.com>
Date: Mon, 26 Feb 2024 14:29:36 +0100
Subject: [PATCH] UI Tweaks
---
app/Properties/Strings.Designer.cs | 23 ++++++++++++++++-------
app/Properties/Strings.resx | 5 ++++-
app/Settings.Designer.cs | 4 ++--
app/Settings.cs | 1 +
4 files changed, 23 insertions(+), 10 deletions(-)
diff --git a/app/Properties/Strings.resx b/app/Properties/Strings.resx
index 64eb9e57..4855137b 100644
--- a/app/Properties/Strings.resx
+++ b/app/Properties/Strings.resx
@@ -330,6 +330,9 @@
Disable Controller
+
+ Disable on lid close
+
Disable screen overdrive
@@ -699,7 +702,7 @@ Do you still want to continue?
Turned off
- Turn off on battery
+ Disable on battery
Routes laptop screen to dGPU, maximizing FPS
diff --git a/app/Settings.Designer.cs b/app/Settings.Designer.cs
index 5d61560c..492a9956 100644
--- a/app/Settings.Designer.cs
+++ b/app/Settings.Designer.cs
@@ -192,7 +192,7 @@ namespace GHelper
//
checkMatrixLid.AutoSize = true;
checkMatrixLid.ForeColor = SystemColors.GrayText;
- checkMatrixLid.Location = new Point(286, 126);
+ checkMatrixLid.Location = new Point(275, 126);
checkMatrixLid.Margin = new Padding(8, 4, 8, 4);
checkMatrixLid.Name = "checkMatrixLid";
checkMatrixLid.Size = new Size(253, 36);
@@ -326,7 +326,7 @@ namespace GHelper
checkMatrix.Location = new Point(27, 126);
checkMatrix.Margin = new Padding(8, 4, 8, 4);
checkMatrix.Name = "checkMatrix";
- checkMatrix.Size = new Size(249, 36);
+ checkMatrix.Size = new Size(241, 36);
checkMatrix.TabIndex = 19;
checkMatrix.Text = Properties.Strings.TurnOffOnBattery;
checkMatrix.UseVisualStyleBackColor = true;
diff --git a/app/Settings.cs b/app/Settings.cs
index f4198670..89c7b118 100644
--- a/app/Settings.cs
+++ b/app/Settings.cs
@@ -85,6 +85,7 @@ namespace GHelper
labelPeripherals.Text = Properties.Strings.Peripherals;
checkMatrix.Text = Properties.Strings.TurnOffOnBattery;
+ checkMatrixLid.Text = Properties.Strings.DisableOnLidClose;
checkStartup.Text = Properties.Strings.RunOnStartup;
buttonMatrix.Text = Properties.Strings.PictureGif;
diff --git a/app/Properties/Strings.Designer.cs b/app/Properties/Strings.Designer.cs
index ac031247..0c57f92b 100644
--- a/app/Properties/Strings.Designer.cs
+++ b/app/Properties/Strings.Designer.cs
@@ -699,6 +699,15 @@ namespace GHelper.Properties {
}
}
+ ///
+ /// Looks up a localized string similar to Disable on lid close.
+ ///
+ internal static string DisableOnLidClose {
+ get {
+ return ResourceManager.GetString("DisableOnLidClose", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Disable screen overdrive.
///
@@ -790,9 +799,9 @@ namespace GHelper.Properties {
return ResourceManager.GetString("EnergySettings", resourceCulture);
}
}
-
+
///
- /// Looks up a localized string similar to Export.
+ /// Looks up a localized string similar to Export Profile.
///
internal static string Export {
get {
@@ -1024,9 +1033,9 @@ namespace GHelper.Properties {
return ResourceManager.GetString("ImageRotation", resourceCulture);
}
}
-
+
///
- /// Looks up a localized string similar to Import.
+ /// Looks up a localized string similar to Import Profile.
///
internal static string Import {
get {
@@ -1294,9 +1303,9 @@ namespace GHelper.Properties {
return ResourceManager.GetString("MouseButtonResponse", resourceCulture);
}
}
-
+
///
- /// Looks up a localized string similar to Import failed. Selected file is not a valid mouse profile or corrutpted.
+ /// Looks up a localized string similar to Import failed. Selected file is not a valid mouse profile or corrutpted..
///
internal static string MouseImportFailed {
get {
@@ -1800,7 +1809,7 @@ namespace GHelper.Properties {
}
///
/// Looks up a localized string similar to Turn off on battery.
///
internal static string TurnOffOnBattery {
get {
@@ -1800,7 +1809,7 @@ namespace GHelper.Properties {
}
///
- /// Looks up a localized string similar to Turn off on battery.
+ /// Looks up a localized string similar to Disable on battery.
///
internal static string TurnOffOnBattery {